pub enum KalmanVariant {
ReferenceUpdate,
DeviationTracking,
}Variants
ReferenceUpdate
Configures the filter as a standard Extended Kalman Filter (EKF) update, updating the full reference state in the process’ propagator at each measurement update.
DeviationTracking
Tracks the state deviation (formerly called Classical Kalman Filter (CKF)) and does not update the reference in the process’ propagator.